Index: /trunk/tools/generic_tools.py
===================================================================
--- /trunk/tools/generic_tools.py	(revision 996)
+++ /trunk/tools/generic_tools.py	(revision 997)
@@ -36,5 +36,5 @@
 # dictionary_key: Function to provide the first key in a dictionay with a given value
 # dictionary_key_list: Function to provide the first key in a dictionay of lists with a given value
 # dictVeysVals_stringList: Function to provide strings from a dictionary with keys which contain values of lists
 # files_folder_HMT: Function to retrieve a list of files from a folder [fold] and files with [head]*[middle]*[tail]
 # get_configuration: Function to get the configuration from an ASCII external file
@@ -7918,5 +7918,5 @@
 def str_list(string, cdiv):
     """ Function to obtain a list from a string givin a split character
-      string= Strring from which to obtain a list ('None' for None)
+      string= String from which to obtain a list ('None' for None)
       cdiv= character to use to split the string
     >>> str_list('1:@#:$:56', ':')
@@ -8208,5 +8208,5 @@
     return newdictv
 
-def dictVeysVals_stringList(dictv,cD=',',cK='@',cV='|'):
+def dictKeysVals_stringList(dictv,cD=',',cK='@',cV='|'):
     """ Function to provide strings from a dictionary with keys which contain values of lists
       dictv= dictionary with the values
@@ -8215,7 +8215,8 @@
       cV= character to use to separate the values for each key
     >>> dictvals = {'Spain': ['Madrid', 'Santander', 'Sevilla', 'Toledo'], 'France': ['Paris', 'Marseille', 'Tolouse']}
+    >>> dictKeysVals_stringList(dictvals)
     Spain@Madrid|Santander|Sevilla|Toledo,France@Paris|Marseille|Tolouse
     """
-    fname = 'dictVeysVals_stringList'
+    fname = 'dictKeysVals_stringList'
 
     ik = 1
@@ -36,5 +36,5 @@
 # dictionary_key: Function to provide the first key in a dictionay with a given value
 # dictionary_key_list: Function to provide the first key in a dictionay of lists with a given value
-# dictVeysVals_stringList: Function to provide strings from a dictionary with keys which contain values of lists
+# dictKeysVals_stringList: Function to provide strings from a dictionary with keys which contain values of lists
 # files_folder_HMT: Function to retrieve a list of files from a folder [fold] and files with [head]*[middle]*[tail]
 # get_configuration: Function to get the configuration from an ASCII external file
